@@ -397,7 +397,7 @@ class LDLE:
     def fit(self, X = None, d_e = None, ddX = None):
         """Run the algorithm. Either X or d_e must be supplied.
         
-        Parmeters
+        Parameters
         ---------
         X : array shape (n_samples, n_features)
             A 2d array containing data representing a manifold.
